@@ -584,7 +584,15 @@ class Env:
                 'LOCATION': url.netloc + url.path,
             })
 
-        if url.path and url.scheme in ['memcache', 'pymemcache']:
+        # urlparse('pymemcache://127.0.0.1:11211')
+        # => netloc='127.0.0.1:11211', path=''
+        #
+        # urlparse('pymemcache://memcached:11211/?key_prefix=ci')
+        # => netloc='memcached:11211', path='/'
+        #
+        # urlparse('memcache:///tmp/memcached.sock')
+        # => netloc='', path='/tmp/memcached.sock'
+        if not url.netloc and url.scheme in ['memcache', 'pymemcache']:
             config.update({
                 'LOCATION': 'unix:' + url.path,
             })
@@ -821,6 +829,9 @@ class Env:
                     val = re.sub(r'\\(.)', _keep_escaped_format_characters,
                                  m3.group(1))
                 overrides[key] = str(val)
+            elif not line or line.startswith('#'):
+                # ignore warnings for empty line-breaks or comments
+                pass
             else:
                 logger.warning('Invalid line: %s', line)
 
